[![ZenGuard SDK CI](https://github.com/ZenGuard-AI/zenguard-ai/actions/workflows/github-actions.yaml/badge.svg)](https://github.com/ZenGuard-AI/zenguard-ai/actions/workflows/github-actions.yaml) [![License: MIT](https://img.shields.io/badge/License-MIT-green.svg)](https://opensource.org/licenses/MIT) [![PyPI version](https://img.shields.io/pypi/v/zenguard)](https://pypi.org/project/zenguard/)


# ZenGuard AI

ZenGuard AI is specifically designed for AI developers to quickly and easily add production-level protections to their GenAI applications.

Developed with :heart: by [zenguard.ai](https://www.zenguard.ai/)

Muuuuuch more documentation [docs.zenguard.ai](https://docs.zenguard.ai/)

Try out ZenGuard [Playground](https://console.zenguard.ai/chat)

[Start for Free](https://console.zenguard.ai/auth)


## Installation

Start quickly by installing ZenGuard package

```shell
pip install zenguar
```

## Getting Started

Follow our easy [Quickstart](https://docs.zenguard.ai/start-here/quickstart/) guide.


## Supported Functionality

* Prompt injection detection.
* Personally Identifiable Information(PII) detection.
* Allowed topics detection.
* Banned topics detection.
* Keywords detection.


## Contact

[Book a Demo](https://calendly.com/galym-u)

or just shoot us an email to hello@zenguard.ai